@@ -15,9 +15,13 @@ Readonly my $AFTER_COMMA        => 'after-comma';
 Readonly my $BEFORE_COMMA       => 'before-comma';
 Readonly my $AFTER_FAT_COMMA    => 'after-fat-comma';
 Readonly my $BEFORE_FAT_COMMA   => 'before-fat-comma';
+Readonly my $AFTER_COMPOUND     => 'after-compound';
 
 sub register {
-    return ('PPI::Token::Operator' => \&handle_operator );
+    return (
+            'PPI::Token::Operator'     => \&handle_operator,
+            'PPI::Statement::Compound' => \&handle_compound,
+        );
 }
 
 sub new {
@@ -26,7 +30,7 @@ sub new {
     my $self = $class->SUPER::new($config);
     
     # Keep configuration local
-    foreach ($AFTER_COMMA, $BEFORE_COMMA, $AFTER_FAT_COMMA, $BEFORE_FAT_COMMA) {
+    foreach ($AFTER_COMMA, $BEFORE_COMMA, $AFTER_FAT_COMMA, $BEFORE_FAT_COMMA, $AFTER_COMPOUND) {
         $self->{$_} = as_true($config->get_directive($_));
     }
 
@@ -38,17 +42,25 @@ sub handle_operator {
 
     my @problems;
 
+    push @problems, $self->_handle_comma($operator, $file);
+    push @problems, $self->_handle_fat_comma($operator, $file);
+    
+    return @problems;
+}
+
+sub _handle_comma {
+    my ($self, $operator, $file) = @_;
+
+    my @problems;
+
     if ($operator->content() eq ',') {
         if ($self->{$AFTER_COMMA}) {
             # Next sibling should be whitespace
             my $sibling = $operator->next_sibling();
             if ($sibling && ref $sibling && !$sibling->isa('PPI::Token::Whitespace')) {
-                push @problems, make_problem(
-                                             $self->{config}->get_severity($AFTER_COMMA),
+                push @problems, new_problem($self->{config}, $AFTER_COMMA,
                                              qq(Missing whitespace after comma (,)),
-                                             $operator->location,
-                                             $file
-                                         );
+                                             $operator, $file);
             }
         }
         
@@ -56,27 +68,29 @@ sub handle_operator {
             # Previous sibling should be whitespace
             my $sibling = $operator->previous_sibling();
             if ($sibling && ref $sibling && !$sibling->isa('PPI::Token::Whitespace')) {
-                push @problems, make_problem(
-                                             $self->{config}->get_severity($BEFORE_COMMA),
+                push @problems, new_problem($self->{config}, $BEFORE_COMMA,
                                              qq(Missing whitespace before comma (,)),
-                                             $operator->location,
-                                             $file
-                                         );
+                                             $operator, $file);
             }
         }
     }
 
+    return @problems;
+}
+
+sub _handle_fat_comma {
+    my ($self, $operator, $file) = @_;
+
+    my @problems;
+    
     if ($operator->content() eq '=>') {
         if ($self->{$AFTER_FAT_COMMA}) {
             # Next sibling should be whitespace
             my $sibling = $operator->next_sibling();
             if ($sibling && ref $sibling && !$sibling->isa('PPI::Token::Whitespace')) {
-                push @problems, make_problem(
-                                             $self->{config}->get_severity($AFTER_FAT_COMMA),
+                push @problems, new_problem($self->{config}, $AFTER_FAT_COMMA,
                                              qq(Missing whitespace after fat comma (=>)),
-                                             $operator->location,
-                                             $file
-                                         );
+                                             $operator, $file);
             }
         }
 
@@ -84,16 +98,35 @@ sub handle_operator {
             # Previous sibling should be whitespace
             my $sibling = $operator->previous_sibling();
             if ($sibling && ref $sibling && !$sibling->isa('PPI::Token::Whitespace')) {
-                push @problems, make_problem(
-                                             $self->{config}->get_severity($BEFORE_FAT_COMMA),
+                push @problems, new_problem($self->{config}, $BEFORE_FAT_COMMA,
                                              qq(Missing whitespace before fat comma (=>)),
-                                             $operator->location,
-                                             $file
-                                         );
+                                             $operator, $file);
             }
         }
     }
-    
+
+    return @problems;
+}
+
+sub handle_compound {
+    my ($self, $compound, $file) = @_;
+
+    my @problems;
+
+    if ($self->{$AFTER_COMPOUND}) {
+        my @children = $compound->schildren();
+        foreach my $child (@children) {
+            next if !$child->isa('PPI::Token::Word');
+            my $word = $child->content();
+            my $sibling = $child->next_sibling();
+            if (defined $sibling && ref $sibling && !$sibling->isa('PPI::Token::Whitespace')) {
+                push @problems, new_problem($self->{config}, $AFTER_COMPOUND,
+                                             qq('$word' is not followed by whitespace),
+                                             $child, $file);
+            }
+        }
+    }
+
     return @problems;
 }
 
@@ -132,6 +165,12 @@ Checks that there is whitespace before a fat comma (=E<gt>), for example as in C
 
 C<before-fat-comma = true>
 
+=item Whitespace after control keyword in compound statements
+
+Checks that there is whitespace after a control-flow keyword in a compound statement. This means an if, elsif, else, while, for, foreach and continue (C<if (EXPR) { .. }>) but not when they are used as statement modifiers (C<... if EXPR>). For information on compound statements read L<perlsyn/Compound Statements>. Enable this check by setting I<after-compound> to a true value.
+
+C<after-compound = true>
+
 =back
 
 =begin PRIVATE
@@ -152,9 +191,17 @@ Creates a new C<Module::Checkstyle::Check::Package> object.
 
 Called when we encounter a C<PPI::Token::Operator> element.
 
-=item handle_word ($word, $file)
+=item _handle_comma ($operator, $file)
 
-Called when we encounter a C<PPI::Token::Word> element.
+Called by C<handle_operator> to do comma checks.
+
+=item _handle_fat_comma ($operator, $file)
+
+Called by C<handle_operator> to do fat comma checks.
+
+=item handle_compound ($compound, $file)
+
+Called when we encounter a C<PPI::Statement::Compound> element.
 
 =back
 
